#!/user/bin/env python
# coding: utf-8

import os
import sys
import subprocess

class shell:
    def value(cmd):
        try:
            os.system(f'{cmd}')
        except:
            os.system(f'pip3 install --upgrade pip')
            os.system(f'{cmd}')
        a = subprocess.check_output(cmd, shell=True)
        return_value = a.decode('EUC-KR', 'backslashreplace')
        return return_value
    def install(module):
        cmd = f'pip3 install {module}'
        try:
            a = os.system(cmd)
        except:
            os.system('pip3 install --upgrade pip')
            a = os.system(cmd)
        if a == 0:
            print('OK to install!')
        else:
            print('error!')



from setuptools import setup
lond_d = '''
```
pip3 install shellvaluepy
```

```py
#input
from shellvaluepy.info import shell

shell.value('dir')

#output
XXXXX XX XXXX
XXX X XXXXXXXXXXX X X
```

```py
#input
from shellvaluepy.info import shell

shell.install('shell_value')

#output
OK to install!
or
error!
```
'''
setup(name="shellvaluepy",
      version="0.2.4",
      url="https://github.com/hminkoo10/shell_value",
      license="MIT",
      author="hminkoo10",
      author_email="hmin.koo10@gmail.com",
      long_description=lond_d,
      long_description_content_type="text/markdown",
      description="made by hminkoo10, discord : Imposter#2879, email: hmin.koo10@gmail.com",
      packages=['shellvaluepy'],
      install_requires=['subprocess']
      )
      
